# DataPipe Software Integration and Release

This repository defines a central python package `ctao-datapipe`, the software
needed to run workflow steps for the DPPS _Data Processing Pipeline_. The
package includes high-level documentation and specifies fixed dependencies for
all associated DataPipe software such installing a release of this package will
create a reproducible environment. A Docker container is also available, see the
documentation.

## Documentation

-  [DataPipe documentation](http://cta-computing.gitlab-pages.cta-observatory.org/dpps/datapipe/datapipe/latest/)

Documentation for DataPipe Dependencies:

- [ctapipe documentation](ctapipe.readthedocs.io)
- [pyirf documentation](https://cta-observatory.github.io/pyirf/)
